# Generated by Django 3.0.6 on 2020-06-07 09:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_login_history', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='login',
            old_name='owner',
            new_name='user',
        ),
    ]
